OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Φόρτωση προεπισκόπησης ...",
    "Saved" : "Αποθηκεύτηκαν",
    "Admin" : "Διαχειριστής",
    "a safe home for all your data" : "μια ασφαλής τοποθεσία για όλα σας τα δεδομένα",
    "Name cannot be empty" : "Το όνομα δεν μπορεί να είναι κενό",
    "The given name is too long" : "Το όνομα που δόθηκε είναι πολύ μεγάλο",
    "The given web address is too long" : "Η διεύθυνση ιστοσελίδας που δόθηκε είναι πολύ μεγάλη.",
    "The given slogan is too long" : "Το ρητό που δόθηκε είναι πολύ μεγάλο",
    "The given color is invalid" : "Δόθηκε μη έγκυρο χρώμα",
    "The file was uploaded" : "Το αρχείο μεταφορτώθηκε",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Το μεταφορτωμένο αρχείο υπερβαίνει την οδηγία upload_max_filesize στο php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Το μεταφορτωμένο αρχείο υπερβαίνει την οδηγία MAX_FILE_SIZE που καθορίστηκε στην φόρμα HTML.",
    "No file was uploaded" : "Δεν μεταφορτώθηκε κάποιο αρχείο",
    "Missing a temporary folder" : "Λείπει κάποιος προσωρινός φάκελος",
    "Could not write file to disk" : "Αδυναμία εγγραφής αρχείου στον δίσκο",
    "A PHP extension stopped the file upload" : "Ένα πρόσθετο PHP διέκοψε την μεταφόρτωση του αρχείου",
    "No file uploaded" : "Δεν έχει μεταφορτωθεί αρχείο",
    "Unsupported image type" : "Μη υποστηριζόμενος τύπος εικόνας",
    "Theming" : "Προσαρμογή θέματος",
    "Legal notice" : "Νομική ειδοποίηση",
    "Adjust the Nextcloud theme" : "Προσαρμόστε το θέμα του Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Η προσαρμογή θέματος καθιστά δυνατή την εύκολη προσαρμογή της εμφάνισης της εμφάνισης της εγκατάστασής σας καθώς και των υποστηριζόμενων πελατών. Αυτή θα είναι ορατή για όλους τους χρήστες.",
    "Name" : "Όνομα",
    "Reset to default" : "Επαναφορά στα προεπιλεγμένα",
    "Web link" : "Σύνδεσμος ιστού",
    "https://…" : "https://…",
    "Slogan" : "Ρητό",
    "Color" : "Χρώμα",
    "Logo" : "Λογότυπο",
    "Upload new logo" : "Μεταφόρτωση νέου λογοτύπου",
    "Login image" : "Εικόνα εισόδου",
    "Upload new login background" : "Μεταφόρτωση νέου παρασκηνίου εισόδου",
    "Remove background image" : "Αφαίρεση εικόνας παρασκηνίου",
    "Advanced options" : "Επιλογές για προχωρημένους",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Εγκαταστήστε την επέκταση PHP Imagemagick με υποστήριξη SVG εικόνων, για να γίνει αυτόματη δημιουργία favicon βασισμένο πάνω στο μεταφορτωμένο λογότυπο και χρώμα."
},
"nplurals=2; plural=(n != 1);");
